Description: fixes spelling errors reported by lintian info tag spelling-error-in-manpage
Author: Ryan Niebur <ryan@debian.org>

--- a/bin/llt
+++ b/bin/llt
@@ -139,7 +139,7 @@ or
     parameter is the time since epoch
     llt print the date in a readable format
     this option can be repeated multiple times
-    llt will stop executing if no other options or params are choosen
+    llt will stop executing if no other options or params are chosen
 
 =back
 
--- a/bin/storeBackupDel.pl
+++ b/bin/storeBackupDel.pl
@@ -182,7 +182,7 @@ storeBackupDel.pl - this program deletes
 =item B<--keepWeekday>
 
 		    keep backups for the specified days for the specified
-		    amount of time. Overwrites the default values choosen in
+		    amount of time. Overwrites the default values chosen in
 		    --keepAll. 'Mon,Wed:40d Sat:60d10m' means:
 			keep backups of Mon and Wed 40days + 5mins
 			keep backups of Sat 60days + 10mins
--- a/bin/storeBackupUpdateBackup.pl
+++ b/bin/storeBackupUpdateBackup.pl
@@ -153,7 +153,7 @@ storeBackupUpdateBackup.pl - updates / f
 
 =item B<--autorepair>, B<-a>
 
-    repair simple inconsistencies automaticly without
+    repair simple inconsistencies automatically without
     requesting the action
 
 =item B<--print>
@@ -185,7 +185,7 @@ storeBackupUpdateBackup.pl - updates / f
 =item B<--noCompress>
 
     maximal number of parallel compress operations,
-    default = choosen automatically
+    default = chosen automatically
 
 =item B<--checkOnly> B<-c>
 
--- a/bin/storeBackupls.pl
+++ b/bin/storeBackupls.pl
@@ -121,7 +121,7 @@ _
 
 =item B<--verbose>, B<-v>
 
-    additional informations about the backup directories
+    additional information about the backup directories
 
 =item B<--print>
 

--- a/bin/storeBackup.pl
+++ b/bin/storeBackup.pl
@@ -687,7 +687,7 @@ or
 =item B<--noCompress>
 
     maximal number of parallel compress operations,
-    default = choosen automatically
+    default = chosen automatically
 
 =item B<--queueCompress>
 
@@ -764,7 +764,7 @@ or
 =item B<--keepWeekday>
 
     keep backups for the specified days for the specified
-    amount of time. Overwrites the default values choosen in
+    amount of time. Overwrites the default values chosen in
     --keepAll. 'Mon,Wed:40d Sat:60d10m' means:
       keep backups from Mon and Wed 40days + 5mins
       keep backups from Sat 60days + 10mins
@@ -1428,7 +1428,7 @@ $blockDeviceHelp
 ;comprRule=
 
 # maximal number of parallel compress operations,
-# default = choosen automatically
+# default = chosen automatically
 ;noCompress=
 
 # length of queue to store files before compression,
@@ -1500,7 +1500,7 @@ $blockDeviceHelp
 ;keepAll=
 
 # keep backups for the specified days for the specified
 # amount of time. Overwrites the default values choosen in
 # --keepAll. 'Mon,Wed:40d Sat:60d10m' means:
 # keep backups from Mon and Wed 40days + 5mins
 # keep backups from Sat 60days + 10mins
@@ -1500,7 +1500,7 @@ $blockDeviceHelp
 
 # keep backups for the specified days for the specified
-# amount of time. Overwrites the default values choosen in
+# amount of time. Overwrites the default values chosen in
 # --keepAll. 'Mon,Wed:40d Sat:60d10m' means:
 # keep backups from Mon and Wed 40days + 5mins
--- a/bin/storeBackupSearch.pl
+++ b/bin/storeBackupSearch.pl
@@ -155,7 +155,7 @@ You need some basic understanding of lin
 
 =item B<--parJobs>, B<-p>
 
-    number of parallel jobs, default = choosen automaticly
+    number of parallel jobs, default = chosen automatically
 
 =item B<--debug>, B<-d>
 
@@ -173,7 +173,7 @@ You need some basic understanding of lin
 
     Root directories of backups where to search relative
     to backupDir. If no directories are specified, all
-    backups below backupDir are choosen.
+    backups below backupDir are chosen.
 
 =back
 
@@ -238,7 +238,7 @@ my $templateConfigFile = <<EOC;
 # write search result also to file
 ;writeToFile=
 
 # number of parallel jobs, default = choosen automaticly
 ;parJobs=
 
 # debug level, possible values are 0, 1, 2, default = 0
@@ -238,7 +238,7 @@ my $templateConfigFile = <<EOC;
 ;writeToFile=
 
-# number of parallel jobs, default = choosen automaticly
+# number of parallel jobs, default = chosen automatically
 ;parJobs=
 